@@ -6,8 +6,6 @@ from lunar.config import Config
 from lunar.lunar_client import LunarClient
 from lunar.rec.recommendations.models import RecommendationIn, RecommendationOut
 
-LUNAR_RECOMMENDATIONS_API_URL = "/v1/recommend"
-
 loop = asyncio.get_event_loop()
 
 
@@ -27,10 +25,6 @@ class RecommendationClient(LunarClient):
     def __init__(self, config: Config):
         super().__init__(config)
 
-        self.api_url = (
-            LUNAR_RECOMMENDATIONS_API_URL if config.ENV == "LOCAL" else f"/api{LUNAR_RECOMMENDATIONS_API_URL}"
-        )
-
     async def recommend_async(
         self, id: str, channel_id: str, params: Dict[str, Any] = dict(), headers: Dict[str, Any] = dict()
     ) -> Dict[str, Any]:
@@ -56,7 +50,9 @@ class RecommendationClient(LunarClient):
 
         data = RecommendationIn(id=id, channel_id=channel_id, params=params)
 
-        body = await self._request(method="POST", url=self.api_url, data=data.dict(), params=params, headers=headers)
+        body = await self._request(
+            method="POST", url=self.config.API_PATH, data=data.dict(), params=params, headers=headers
+        )
         result = RecommendationOut(**body["data"])
 
         return result.dict()
